use crate::prelude::*;

pub struct Player {
    pub position: Point,
}

impl Player {
    pub fn new(position: Point) -> Self {
        Self {
            position,
        }
    }

    pub fn render(&self, ctx: &mut BTerm) {
        ctx.set(self.position.x, self.position.y, GREEN, BLACK, to_cp437('@'));
    }

    pub fn update(&mut self, ctx: &mut BTerm, map: &Map) {
        if let Some(key) = ctx.key {
            let delta = match key {
                VirtualKeyCode::A => Point::new(-1, 0),
                VirtualKeyCode::S => Point::new(0, 1),
                VirtualKeyCode::D => Point::new(1, 0),
                VirtualKeyCode::W => Point::new(0, -1),
                _ => Point::zero(),
            };

            let new_position = self.position + delta;

            if map.is_in_bounds_point(new_position) && map.tile_at_point(new_position).can_enter() {
                self.position = new_position;
            }
        }
    }
}
